#
# spec file for package glm
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           glm
Version:        0.9.7.5
Release:        lp151.3.3.1
Summary:        Header only C++ mathematics library for graphics
License:        MIT
Group:          Development/Libraries/C and C++
Url:            http://glm.g-truc.net/
Source0:        https://github.com/g-truc/glm/releases/download/%{version}/%{name}-%{version}.zip
# PATCH-FIX-OPENSUSE glm-cmake-config.patch -- Fix cmake config location
Patch1:         glm-cmake-config.patch
# PATCH-FIX-UPSTREAM glm-pkgconfig.patch
Patch2:         glm-pkgconfig.patch
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  unzip
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
OpenGL Mathematics (GLM) is a header only C++ mathematics library for graphics
software based on the OpenGL Shading Language (GLSL) specification.

GLM provides classes and functions designed and implemented with the same naming
conventions and functionalities than GLSL so that when a programmer knows GLSL,
he knows GLM as well which makes it really easy to use.

%package        devel
Summary:        Header only C++ mathematics library for graphics
Group:          Development/Libraries/C and C++
Requires:       cmake

%description    devel
OpenGL Mathematics (GLM) is a header only C++ mathematics library for graphics
software based on the OpenGL Shading Language (GLSL) specification.

GLM provides classes and functions designed and implemented with the same naming
conventions and functionalities than GLSL so that when a programmer knows GLSL,
he knows GLM as well which makes it really easy to use.

%package        doc
Summary:        Documentation for GLM library
Group:          Documentation/Other
BuildArch:      noarch

%description    doc
This package provides the documentation for GLM library.

%prep
%setup -q -n %{name}
# Fix wrong-file-end-of-line-encoding
sed -i 's/\r//' copying.txt
sed -i 's/\r//' readme.md
sed -i 's/\r//' doc/api/doxygen.css
sed -i 's/\r//' doc/api/tabs.css
%ifarch %{ix86}
sed -i '/glmCreateTestGTC(core_func_exponential)/d' test/core/CMakeLists.txt
# https://github.com/g-truc/glm/issues/212
sed -i '/glmCreateTestGTC(gtc_packing)/d' test/gtc/CMakeLists.txt
%if 0%{?suse_version} <= 1320
# https://github.com/g-truc/glm/issues/296
sed -i '/glmCreateTestGTC(gtc_integer)/d' test/gtc/CMakeLists.txt
%endif
%if 0%{?suse_version} <= 1320
sed -i '/glmCreateTestGTC(gtx_common)/d' test/gtx/CMakeLists.txt
%endif
%endif
%patch1
%patch2 -p1

%build
%cmake \
  -DCMAKE_CXX_FLAGS="%{optflags} -fPIC -fno-strict-aliasing" \
  -DGLM_TEST_ENABLE=ON
make %{?_smp_mflags}

%install
%cmake_install
%fdupes -s %{buildroot}

%check
%ctest

%files devel
%defattr(-,root,root,-)
%{_includedir}/glm/
%{_libdir}/cmake/%{name}/
%{_libdir}/pkgconfig/%{name}.pc
%doc copying.txt

%files doc
%defattr(-,root,root,-)
%doc doc/api
%doc doc/glm.pdf
%doc readme.md

%changelog
* Mon May 20 2019 Luigi Baldoni <aloisio@gmx.com>
- Added glm-pkgconfig.patch to create glm.pc file
  (fixes bsc#1135667)
* Wed Jun 29 2016 mpluskal@suse.com
- Update to 0.9.7.5
  * Added Visual C++ Clang toolset detection
  * Fixed uaddCarry warning #497
  * Fixed roundPowerOfTwo and floorPowerOfTwo #503
  * Fixed Visual C++ SIMD instruction set automatic detection in 64
    bits
  * Fixed to_string when used with GLM_FORCE_INLINE #506
  * Fixed GLM_FORCE_INLINE with binary vec4 operators
* Mon Mar 21 2016 dmitry_r@opensuse.org
- Update to version 0.9.7.4
- Fix cmake config location
  * glm-cmake-config.patch
- Drop obsolete
  * glm-0.9.5.3-no_gtc_packing_test.patch
- Drop aliasing.patch, use -fno-strict-aliasing
* Thu Sep 25 2014 schwab@suse.de
- aliasing.patch: fix strict aliasing issues
* Fri May 16 2014 fstrba@suse.com
- Version bump to 0.9.5.3
- Add a patch to disable gtc_packing test that fails on some i586
  systems:
  * glm-0.9.5.3-no_gtc_packing_test.patch
- Add %%fdupes to reduce size
* Mon Mar 24 2014 tchvatal@suse.com
- Version bump to 0.9.5.2:
  * Various bug fixes
  * MIT only license
- Remove no longer needed patch:
  * glm-nonx86.patch
- Use cmake macros to build
* Thu Aug  1 2013 dvaleev@suse.com
- convert sources to UNIX format using dos2unix
- fix build on non x86 architectures (glm-nonx86.patch)
* Thu Jul 18 2013 cfarrell@suse.com
- license update: MIT and GPL-2.0+
  glm-0.9.4.4/test/external/gli/core/shared_ptr.inl is GPL licensed
* Wed Jul 10 2013 dmitry_r@opensuse.org
- Update to version 0.9.4.4
  * Promoted GTC_espilon extension
  * Promoted GTC_ulp extension
  * Removed GLM website from the source repository
  * Added GLM_FORCE_RADIANS so that all functions takes radians for arguments
* Sun Mar  3 2013 jengelh@inai.de
- Add missing BuildRoot directive (resolve SLE build failure)
* Tue Sep  4 2012 adam@mizerski.pl
- update to 0.9.3.4
  - A lot happend since last update.
    Changelog available at http://glm.g-truc.net/
* Sun Feb  5 2012 jengelh@medozas.de
- Remove redundant tags/sections
* Fri Sep 16 2011 adam@mizerski.pl
- update to 0.9.2.4
  - Fixed extensions bugs
* Mon Jun 27 2011 adam@mizerski.pl
- update to 0.9.2.3
  - Fixed build issues
- update to 0.9.2.2
  - Expend matrix constructors flexibility
  - Improved quaternion implementation
  - Fixed many warnings across platforms and compilers
* Thu May 26 2011 adam@mizerski.pl
- update to 0.9.2.1
  - Automatically detect CUDA support
  - Improved compiler detection
  - Fixed errors and warnings in VC with C++ extensions disabled
  - Fixed and tested GLM_GTX_vector_angle
  - Fixed and tested GLM_GTX_rotate_vector
* Sat May 14 2011 adam@mizerski.pl
- new package
